@@ -11,6 +11,7 @@ import sys
 from IPython.core.error import TryNext, UsageError
 from IPython.core.magic import Magics, magics_class, line_magic
 from IPython.lib.clipboard import ClipboardEmpty
+from IPython.testing.skipdoctest import skip_doctest
 from IPython.utils.text import SList, strip_email_quotes
 from IPython.utils import py3compat
 
@@ -83,6 +84,7 @@ class TerminalMagics(Magics):
         self.shell.set_autoindent()
         print("Automatic indentation is:",['OFF','ON'][self.shell.autoindent])
 
+    @skip_doctest
     @line_magic
     def cpaste(self, parameter_s=''):
         """Paste & execute a pre-formatted code block from clipboard.
@@ -109,11 +111,11 @@ class TerminalMagics(Magics):
         Just press enter and type -- (and press enter again) and the block
         will be what was just pasted.
 
-        IPython statements (magics, shell escapes) are not supported (yet).
+        Shell escapes are not supported (yet).
 
-        See also
+        See Also
         --------
-        paste: automatically pull code from clipboard.
+        paste : automatically pull code from clipboard.
 
         Examples
         --------
@@ -122,9 +124,19 @@ class TerminalMagics(Magics):
           In [8]: %cpaste
           Pasting code; enter '--' alone on the line to stop.
           :>>> a = ["world!", "Hello"]
-          :>>> print " ".join(sorted(a))
+          :>>> print(" ".join(sorted(a)))
           :--
           Hello world!
+
+        ::
+          In [8]: %cpaste
+          Pasting code; enter '--' alone on the line to stop.
+          :>>> %alias_magic t timeit
+          :>>> %t -n1 pass
+          :--
+          Created `%t` as an alias for `%timeit`.
+          Created `%%t` as an alias for `%%timeit`.
+          354 ns ± 224 ns per loop (mean ± std. dev. of 7 runs, 1 loop each)
         """
         opts, name = self.parse_options(parameter_s, 'rqs:', mode='string')
         if 'r' in opts:
@@ -164,9 +176,9 @@ class TerminalMagics(Magics):
 
         IPython statements (magics, shell escapes) are not supported (yet).
 
-        See also
+        See Also
         --------
-        cpaste: manually paste code into terminal until you mark its end.
+        cpaste : manually paste code into terminal until you mark its end.
         """
         opts, name = self.parse_options(parameter_s, 'rq', mode='string')
         if 'r' in opts:
@@ -181,16 +193,15 @@ class TerminalMagics(Magics):
             else:
                 error('Could not get text from the clipboard.')
             return
-        except ClipboardEmpty:
-            raise UsageError("The clipboard appears to be empty")
+        except ClipboardEmpty as e:
+            raise UsageError("The clipboard appears to be empty") from e
 
         # By default, echo back to terminal unless quiet mode is requested
         if 'q' not in opts:
-            write = self.shell.write
-            write(self.shell.pycolorize(block))
-            if not block.endswith('\n'):
-                write('\n')
-            write("## -- End pasted text --\n")
+            sys.stdout.write(self.shell.pycolorize(block))
+            if not block.endswith("\n"):
+                sys.stdout.write("\n")
+            sys.stdout.write("## -- End pasted text --\n")
 
         self.store_or_execute(block, name)
 
